import tkinter as tk
from tkinter import LabelFrame
from tkinter.scrolledtext import ScrolledText


class LogFrame(LabelFrame):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.Gui_Show()
        self.rowconfigure(0,weight=1)
        self.columnconfigure(0,weight=1)
    def Gui_Show(self):
        self.scText=ScrolledText(self)
        self.scText.grid(row=0,column=0,sticky="WNSE")
    def m_Gui_LogClear(self):
        self.scText.delete(0.0,'end')
    def m_Gui_LogInsert(self,msg,see_end:bool=False):
        self.scText.insert('end',msg+"\n")
        if see_end:
            self.scText.see('end')



import tkinter as tk

import time
class StatusFrame(tk.Frame):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.strvar = tk.StringVar()
        self.MesList=["","","",""]
        self.columnconfigure(0,weight=1)
        self.statusbar = tk.Label(self,relief="sunken",anchor="sw",textvariable=self.strvar)
        
        self.statusbar.grid(column=0,row=0,sticky="WE")
        self.RunThread()
    def ShowMessage(self):
        while True:
            self.m_UpdateTime()
            self.strvar.set(" || ".join(self.MesList))
            time.sleep(1)
    @staticmethod
    def GetTimeStr():
        '''
        返回日期字符串 如211103_161722
        '''
        return time.strftime(" %y年%m月%d日 %H:%M:%S", time.localtime())
   
    def RunThread(self):
        self.after(500,self.RunThread)
        self.m_UpdateStatus(0)
        self.m_UpdatePercent(0)
        self.ShowMessage()

    def m_UpdateInfo(self,msg):
        self.MesList[3]="Info:{}".format(msg)
    def m_UpdateStatus(self,index):
        '''
        0.Ready 1.Running 2.Finish 3.Fail 
        '''
        self.MesList[2]=["Ready","Running","Finish","Fail"][index]
        self.statusbar["bg"]=["green","yellow","green","red"][index]
        if index == 0 or index == 2:
            self.m_UpdatePercent([0,100][index>0])
    def m_UpdatePercent(self,pros):
        self.MesList[1]="{}>{} {:>3d}%".format("="*int(pros/10),"="*(10-int(pros/10)),pros)
    def m_UpdateTime(self):
        self.MesList[0]=self.GetTimeStr()




from tkinter import Label
import tkinter as tk
class RollingLabel(Label):
    def __init__(self,*argv,textvar:tk.StringVar="",fps=500,**kwords):

        super().__init__(*argv,**kwords)
        self._roing_run = True
        self._label_var = textvar
        self._fps = fps
        if textvar !="":
            self["text"]=self._label_var.get()+" <"
            self._label_var.trace("w",self.callback)
        self.roing()
    def callback(self,*args):
        self["text"]=self._label_var.get()+" <"
    def roing(self):
        word = self["text"]
        if len(word)>1 and self._roing_run:
            self["text"]=word[1:]+word[0]
        self.after(self._fps,self.roing)
    def update_fps(self,fps:int):
        self._fps = fps
    def roing_pause(self,switch=True):
        self._roing_run=switch

    

if __name__=="__main__":
    pass
    # win = tk.Tk()
    # x = tk.StringVar()
    # x.set("1234567890")
    # RollingLabel(textvar=x,fps=100).pack()

    # x.set("111222333")
    # win.mainloop()


import tktkrs #tktkrs ==0.1.2
from tkinter import Label
import tkinter as tk


class GifFrame(Label):
    def __init__(self,*argv,gif_path:str,**kwords):
        super().__init__(*argv,**kwords)

        self.gifinfo:list = tktkrs.gif_info(gif_path)
        self.frame_index =-1
        self.frame_all = len(self.gifinfo)
        print(self.frame_all)
        self.frames = [tk.PhotoImage(file=gif_path, format='gif -index %i' %(i)) for i in range(self.frame_all)]
        self.run()
    def run(self):
        self.frame_index=(self.frame_index+1)%self.frame_all
        self["image"] =  self.frames[self.frame_index]#self.iter.__sizeof__()
        self.after(self.gifinfo[self.frame_index],self.run)

if __name__=="__main__":
    win = tk.Tk()
    xe = GifFrame(win,gif_path=r"C:\exp1.gif")
    xe.grid(column=0,row=0,sticky="WNSE")
    win.columnconfigure(0,weight=1)
    win.rowconfigure(0,weight=1)
    win.mainloop()